@@ -29,19 +29,23 @@ class RecordingsDialog(gtk.Dialog):
     def __init__(self, parent=None):
         gtk.Dialog.__init__(self, title=_("Recordings"),
             parent=parent,
-            flags=gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
-            buttons=(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE))
+            flags=gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT)
             
-        self.set_size_request(600, 400)
-        self.vbox.set_spacing(6)
+        self.set_default_size(600, 400)
+        self.set_has_separator(False)
+        self.set_border_width(5)
+        
+        close_button = self.add_button(gtk.STOCK_CLOSE, gtk.RESPONSE_CLOSE)
+        close_button.grab_default()
             
-        hbox_main = gtk.HBox(spacing=6)
+        hbox_main = gtk.HBox(spacing=12)
+        hbox_main.set_border_width(5)
         hbox_main.show()
         self.vbox.pack_start(hbox_main)
             
         self._model = RecordingsStore()
-        self._model.set_sort_column_id(RecordingsStore.COL_START,
-            gtk.SORT_ASCENDING)
+        self._model.set_sort_func(RecordingsStore.COL_START,
+            self._datetime_sort_func)
         self._view = RecordingsView(self._model)
         self._view.connect("button-press-event", self._on_recording_selected)
         self._view.set_property("rules-hint", True)
@@ -58,7 +62,7 @@ class RecordingsDialog(gtk.Dialog):
         hbox_main.pack_start(scrolledwindow)
         
         buttonbox = gtk.VButtonBox()
-        buttonbox.set_spacing(3)
+        buttonbox.set_spacing(6)
         buttonbox.set_layout(gtk.BUTTONBOX_START)
         buttonbox.show()
         hbox_main.pack_start(buttonbox, False)
@@ -88,7 +92,7 @@ class RecordingsDialog(gtk.Dialog):
             dialog = gtk.MessageDialog(parent=self,
                     flags=gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
                     type=gtk.MESSAGE_QUESTION, buttons=gtk.BUTTONS_YES_NO)
-            dialog.set_markup(_("<big><span weight=\"bold\">Delete selected recordings?</span></big>"))
+            dialog.set_markup("<big><span weight=\"bold\">%s</span></big>" % _("Delete selected recordings?"))
             response = dialog.run()
             dialog.destroy()
             if response == gtk.RESPONSE_YES:
@@ -112,4 +116,10 @@ class RecordingsDialog(gtk.Dialog):
     def _delete_callback(self, success):
         if not success:
             global_error_handler("Could not delete recording")
+
+    def _datetime_sort_func(treemodel, iter1, iter2):
+        d1 = treemodel[iter1][RecordingsStore.COL_START]
+        d2 = treemodel[iter2][RecordingsStore.COL_START]
+        return cmp(d1, d2)
+
         
